(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     68729,       1515]
NotebookOptionsPosition[     68964,       1501]
NotebookOutlinePosition[     69429,       1521]
CellTagsIndexPosition[     69386,       1518]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Stress Transformation\n",
 StyleBox["Revised by Zhelong He, Marek-Jerzy Pindera, University of \
Virginia, 2018-03-27\nPrototype developed by Nick Bongiardina et al, \
University of Colorado Boulder",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell[TextData[{
 "This module is revised on the basis of the prototype developed by Nick \
Bongiardina et al to show the idea of stress transformation as well as Mohr\
\[CloseCurlyQuote]s Circle for plane stress problem. \nThe state of plane \
stress at a point is uniquely represented by two normal stress components and \
one shear stress component acting on an element. These three component will \
be different for each specific orientation \[Theta] of the element at the \
point. Specifically, if the stress state for a given element is known, with \
the two normal stresses and one shear stress represented by ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", "x"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", "y"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", "xy"], TraditionalForm]]],
 "; after a rotation of an angle \[Theta], the stresses change to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", 
    RowBox[{"x", "'"}]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", 
    RowBox[{"y", "'"}]], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", 
    RowBox[{
     RowBox[{"x", "'"}], 
     RowBox[{"y", "'"}]}]], TraditionalForm]]],
 ", and the relations between these two sets of stress, or stress \
transformation equation can be written as "
}], "Text"],

Cell[TextData[Cell[BoxData[{
 FormBox[
  RowBox[{
   SubscriptBox["\[Sigma]", 
    RowBox[{"x", "'"}]], "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["\[Sigma]", "x"], " ", "+", " ", 
      SubscriptBox["\[Sigma]", "y"]}], "2"], "+", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["\[Sigma]", "x"], " ", "-", " ", 
       SubscriptBox["\[Sigma]", "y"]}], "2"], "cos2\[Theta]"}], "+", 
    RowBox[{
     SubscriptBox["\[Tau]", "xy"], "sin2\[Theta]"}]}]}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   SubscriptBox["\[Sigma]", 
    RowBox[{"y", "'"}]], "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["\[Sigma]", "x"], " ", "+", " ", 
      SubscriptBox["\[Sigma]", "y"]}], "2"], "-", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["\[Sigma]", "x"], " ", "-", " ", 
       SubscriptBox["\[Sigma]", "y"]}], "2"], "cos2\[Theta]"}], "-", 
    RowBox[{
     SubscriptBox["\[Tau]", "xy"], "sin2\[Theta]"}]}]}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   SubscriptBox["\[Tau]", 
    RowBox[{
     RowBox[{"x", "'"}], 
     RowBox[{"y", "'"}]}]], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Sigma]", "x"], " ", "-", " ", 
        SubscriptBox["\[Sigma]", "y"]}], "2"]}], "sin2\[Theta]"}], "+", 
    RowBox[{
     SubscriptBox["\[Tau]", "xy"], "cos2\[Theta]"}]}]}], 
  TraditionalForm]}]]], "Text",
 TextAlignment->Center],

Cell["\<\
After eliminate the parameter \[Theta] we can get the following equation \
\>", "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"[", 
      RowBox[{
       SubscriptBox["\[Sigma]", 
        RowBox[{"x", "'"}]], "-", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          SubscriptBox["\[Sigma]", "x"], " ", "+", " ", 
          SubscriptBox["\[Sigma]", "y"]}], "2"], ")"}]}], "]"}], "2"], "+", 
    SuperscriptBox[
     SubscriptBox["\[Tau]", 
      RowBox[{
       RowBox[{"x", "'"}], 
       RowBox[{"y", "'"}]}]], "2"]}], "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Sigma]", "x"], " ", "-", " ", 
        SubscriptBox["\[Sigma]", "y"]}], "2"], ")"}], "2"], "+", 
    SuperscriptBox[
     SubscriptBox["\[Tau]", "xy"], "2"]}]}], TraditionalForm]]]], "Text",
 TextAlignment->Center],

Cell[TextData[{
 "Which is the equation of Mohr\[CloseCurlyQuote]s Circle for plane stress \
problem. Once we set the stress of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", "x"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", "y"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", "xy"], TraditionalForm]]],
 " at 0 degree, the Mohr\[CloseCurlyQuote]s Circle can be drawn in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Sigma]", 
     RowBox[{"x", "'"}]], "-", 
    SubscriptBox["\[Tau]", 
     RowBox[{
      RowBox[{"x", "'"}], 
      RowBox[{"y", "'"}]}]]}], TraditionalForm]]],
 " plane, and the point represent 0 degree can be determined. Then, according \
to the stress transformation equation, we can easily determine the stress for \
the same element with an orientation of angle \[Theta]. \nThe following \
module is used to show such process. Give the stress at 0 degree first, and \
then give the orientation angle \[Theta], see how the stress of the element \
change. Also see the stress plot for the whole range of orientation. "
}], "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{CloudObject`Private`cs$$ = False, 
    CloudObject`Private`path$$ = 1, CloudObject`Private`pj$$ = False, 
    CloudObject`Private`plottype$$ = 1, CloudObject`Private`rightplot$$ = 0, 
    CloudObject`Private`smax$$ = 100, CloudObject`Private`sx$$ = True, 
    CloudObject`Private`sxy$$ = False, CloudObject`Private`sy$$ = False, 
    CloudObject`Private`ticks$$ = False, CloudObject`Private`\[Theta]d$$ = 0, 
    CloudObject`Private`\[Sigma]x$$ = CloudObject`Private`smax$$, 
    CloudObject`Private`\[Sigma]y$$ = 0, CloudObject`Private`\[Tau]xy$$ = 0, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[CloudObject`Private`\[Sigma]x$$], CloudObject`Private`smax$$, 
       Row[{
         Subscript["\[Sigma]", 
          Style["x", Italic]], 
         Spacer[4.5]}]}, 
      Dynamic[-CloudObject`Private`smax$$], 
      Dynamic[CloudObject`Private`smax$$], 0.1}, {{
       Hold[CloudObject`Private`\[Sigma]y$$], 0, 
       Row[{
         Subscript["\[Sigma]", 
          Style["y", Italic]], 
         Spacer[3]}]}, 
      Dynamic[-CloudObject`Private`smax$$], 
      Dynamic[CloudObject`Private`smax$$], 0.1}, {{
       Hold[CloudObject`Private`\[Tau]xy$$], 0, 
       Row[{
         Subscript["\[Tau]", 
          Style["x\[InvisibleComma]y", Italic]]}]}, 
      Dynamic[-CloudObject`Private`smax$$], 
      Dynamic[CloudObject`Private`smax$$], 0.1}, {{
       Hold[CloudObject`Private`path$$], 1, ""}, {1 -> Style[
         Row[{"orientation", 
           Spacer[32.5]}], 12], 2 -> Style[
         Row[{"principal ", "stresses"}], 12], 3 -> Style[
         Row[{"max shear stress", 
           Spacer[3]}], 12]}}, {{
       Hold[CloudObject`Private`\[Theta]d$$], 0, 
       Row[{"\[Theta]", 
         Spacer[2], "(\[Degree])"}]}, 0, 180, 0.1}, {{
       Hold[CloudObject`Private`rightplot$$], 0, 
       Row[{"right plot", 
         Spacer[12]}]}, {5 -> "On", 0 -> "Off"}}, {{
       Hold[CloudObject`Private`plottype$$], 1, 
       Row[{"plot type", 
         Spacer[14.5]}]}, {1 -> " stress plot ", 2 -> " Mohr's circle "}}, {{
       Hold[CloudObject`Private`sx$$], True, 
       Subscript["\[Sigma]", 
        Style["x", Italic]]}, {True, False}}, {{
       Hold[CloudObject`Private`sy$$], False, 
       Subscript["\[Sigma]", 
        Style["y", Italic]]}, {True, False}}, {{
       Hold[CloudObject`Private`sxy$$], False, 
       Subscript["\[Tau]", 
        Style["xy", Italic]]}, {True, False}}, {{
       Hold[CloudObject`Private`pj$$], False, "resolution"}, {True, False}}, {{
       Hold[CloudObject`Private`cs$$], False, "principle stress labels"}, {
      True, False}}, {{
       Hold[CloudObject`Private`ticks$$], False, "axes ticks"}, {
      True, False}}, {
      Hold[
       Grid[{{
          Grid[{{
             Text[
              Style[
               Row[{
                 Style[
                  Subscript["\[Sigma]", "0"], Bold], ", ", 
                 "stresses (MPa) at \[Theta] = ", 
                 NumberForm[0, {4, 1}], "\[Degree]"}], 12]]}, {
             Manipulate`Place[1]}, {
             Manipulate`Place[2]}, {
             Manipulate`Place[3]}}, Alignment -> {Left, Center}], 
          Grid[{{
             Manipulate`Place[4], 
             PaneSelector[{1 -> Row[{
                  Spacer[5], 
                  Manipulate`Place[5], 
                  Spacer[10], 
                  Dynamic[
                   NumberForm[CloudObject`Private`\[Theta]d$$, {4, 1}]]}]}, 
              Dynamic[CloudObject`Private`path$$]]}}, 
           Alignment -> {Left, Top}, Spacings -> {1., 1.}], 
          Grid[{{
             Manipulate`Place[6]}, {
             PaneSelector[{5 -> Manipulate`Place[7]}, 
              Dynamic[CloudObject`Private`rightplot$$]]}, {
             PaneSelector[{6 -> Row[{
                  Manipulate`Place[8], 
                  Manipulate`Place[9], 
                  Manipulate`Place[10]}, 
                 Spacer[10]], 7 -> Grid[{{
                   Manipulate`Place[11], 
                   Manipulate`Place[12], 
                   Manipulate`Place[13]}}, Spacings -> {{0, 1., 1.}, 0}]}, 
              Dynamic[
              CloudObject`Private`rightplot$$ + 
               CloudObject`Private`plottype$$]]}}, 
           Alignment -> {Left, Center}, Spacings -> {1., {0, 0.8, 0.8}}]}}, 
        Alignment -> Top, Spacings -> {{0, 5, 8}, Automatic}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[CloudObject`Private`smax$$], 100}, 0}}, Typeset`size$$ = {
    1036., {267., 276.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, CloudObject`Private`\[Sigma]x$229914$$ = 0,
     CloudObject`Private`\[Sigma]y$229915$$ = 0, 
    CloudObject`Private`\[Tau]xy$229916$$ = 0, 
    CloudObject`Private`path$229917$$ = False, 
    CloudObject`Private`\[Theta]d$229918$$ = 0, 
    CloudObject`Private`rightplot$229919$$ = False, 
    CloudObject`Private`plottype$229920$$ = False, 
    CloudObject`Private`sx$229921$$ = False, CloudObject`Private`sy$229922$$ =
     False, CloudObject`Private`sxy$229923$$ = False, 
    CloudObject`Private`pj$229924$$ = False, CloudObject`Private`cs$229925$$ =
     False, CloudObject`Private`ticks$229926$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {
       CloudObject`Private`cs$$ = False, CloudObject`Private`path$$ = 1, 
        CloudObject`Private`pj$$ = False, CloudObject`Private`plottype$$ = 1, 
        CloudObject`Private`rightplot$$ = 0, CloudObject`Private`smax$$ = 100,
         CloudObject`Private`sx$$ = True, CloudObject`Private`sxy$$ = False, 
        CloudObject`Private`sy$$ = False, CloudObject`Private`ticks$$ = False,
         CloudObject`Private`\[Theta]d$$ = 0, CloudObject`Private`\[Sigma]x$$ = 
        CloudObject`Private`smax$$, CloudObject`Private`\[Sigma]y$$ = 0, 
        CloudObject`Private`\[Tau]xy$$ = 0}, "ControllerVariables" :> {
        Hold[
        CloudObject`Private`\[Sigma]x$$, 
         CloudObject`Private`\[Sigma]x$229914$$, 0], 
        Hold[
        CloudObject`Private`\[Sigma]y$$, 
         CloudObject`Private`\[Sigma]y$229915$$, 0], 
        Hold[
        CloudObject`Private`\[Tau]xy$$, CloudObject`Private`\[Tau]xy$229916$$,
          0], 
        Hold[
        CloudObject`Private`path$$, CloudObject`Private`path$229917$$, False], 
        Hold[
        CloudObject`Private`\[Theta]d$$, 
         CloudObject`Private`\[Theta]d$229918$$, 0], 
        Hold[
        CloudObject`Private`rightplot$$, 
         CloudObject`Private`rightplot$229919$$, False], 
        Hold[
        CloudObject`Private`plottype$$, CloudObject`Private`plottype$229920$$,
          False], 
        Hold[
        CloudObject`Private`sx$$, CloudObject`Private`sx$229921$$, False], 
        Hold[
        CloudObject`Private`sy$$, CloudObject`Private`sy$229922$$, False], 
        Hold[
        CloudObject`Private`sxy$$, CloudObject`Private`sxy$229923$$, False], 
        Hold[
        CloudObject`Private`pj$$, CloudObject`Private`pj$229924$$, False], 
        Hold[
        CloudObject`Private`cs$$, CloudObject`Private`cs$229925$$, False], 
        Hold[
        CloudObject`Private`ticks$$, CloudObject`Private`ticks$229926$$, 
         False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{CloudObject`Private`\[Theta]$, CloudObject`Private`\[Theta]0$, 
         CloudObject`Private`\[Theta]p1$, CloudObject`Private`\[Theta]p2$, 
         CloudObject`Private`\[Theta]s1$, CloudObject`Private`\[Theta]s2$, 
         CloudObject`Private`\[Sigma]ave$, CloudObject`Private`R$, 
         CloudObject`Private`\[Tau]max1$, CloudObject`Private`\[Tau]max2$, 
         CloudObject`Private`\[Sigma]x1$, CloudObject`Private`\[Sigma]y1$, 
         CloudObject`Private`\[Tau]x1y1$, CloudObject`Private`\[Sigma]1$, 
         CloudObject`Private`\[Sigma]2$, CloudObject`Private`stressplot$, 
         CloudObject`Private`mohr$, CloudObject`Private`corner$, 
         CloudObject`Private`\[Theta]1$, CloudObject`Private`scale1$, 
         CloudObject`Private`\[Theta]2$, CloudObject`Private`scale2$, 
         CloudObject`Private`original$, CloudObject`Private`diffelement$, 
         CloudObject`Private`table$, CloudObject`Private`table0$, 
         CloudObject`Private`coordinate$}, 
        Switch[CloudObject`Private`path$$, 1, CloudObject`Private`\[Theta]$ = 
          CloudObject`Private`\[Theta]d$$ (Pi/180), 2, {
          CloudObject`Private`\[Theta]$ = CloudObject`Private`\[Theta]p1$; 
           CloudObject`Private`\[Theta]d$$ = 
            N[CloudObject`Private`\[Theta]p1$ (180/Pi)]; Null}, 3, {
          CloudObject`Private`\[Theta]$ = CloudObject`Private`\[Theta]s1$; 
           CloudObject`Private`\[Theta]d$$ = 
            N[CloudObject`Private`\[Theta]s1$ (180/Pi)]; Null}]; 
        CloudObject`Private`\[Theta]p1$ = (Which[
          CloudObject`Private`\[Sigma]x$$ == CloudObject`Private`\[Sigma]y$$, 
           If[CloudObject`Private`\[Tau]xy$$ < 0, 3 (Pi/4), Pi/4], 
           CloudObject`Private`\[Sigma]x$$ != CloudObject`Private`\[Sigma]y$$, 
           If[
           CloudObject`Private`\[Sigma]x$$ < 
            CloudObject`Private`\[Sigma]y$$, # + Pi/2, 
            If[CloudObject`Private`\[Tau]xy$$ < 0, # + Pi, #]]]& )[
           Quiet[
           0.5 ArcTan[
             2 (CloudObject`Private`\[Tau]xy$$/(
               CloudObject`Private`\[Sigma]x$$ - 
               CloudObject`Private`\[Sigma]y$$))]]]; 
        CloudObject`Private`\[Theta]p2$ = 
         Which[CloudObject`Private`\[Sigma]x$$ == 
           CloudObject`Private`\[Sigma]y$$, 
           If[CloudObject`Private`\[Tau]xy$$ < 0, Pi/4, 3 (Pi/4)], 
           CloudObject`Private`\[Sigma]x$$ != CloudObject`Private`\[Sigma]y$$, 
           If[
           CloudObject`Private`\[Tau]xy$$ < 0, 
            CloudObject`Private`\[Theta]p1$ - Pi/2, 
            CloudObject`Private`\[Theta]p1$ + Pi/2]]; 
        CloudObject`Private`\[Theta]s1$ = (Which[
          CloudObject`Private`\[Tau]xy$$ != 0, 
           If[CloudObject`Private`\[Tau]xy$$ < 0, # + Pi/2, 
            If[
            CloudObject`Private`\[Sigma]x$$ <= 
             CloudObject`Private`\[Sigma]y$$, #, # + Pi]], 
           CloudObject`Private`\[Tau]xy$$ == 0, 
           If[
           CloudObject`Private`\[Sigma]x$$ < CloudObject`Private`\[Sigma]y$$, 
            Pi/4, 3 (Pi/4)]]& )[
           Quiet[
           0.5 ArcTan[(CloudObject`Private`\[Sigma]y$$ - 
               CloudObject`Private`\[Sigma]x$$)/(2 
              CloudObject`Private`\[Tau]xy$$)]]]; 
        CloudObject`Private`\[Theta]s2$ = 
         If[CloudObject`Private`\[Tau]xy$$ < 0, 
           If[
           CloudObject`Private`\[Sigma]x$$ <= CloudObject`Private`\[Sigma]y$$,
             CloudObject`Private`\[Theta]s1$ + Pi/2, 
            CloudObject`Private`\[Theta]s1$ - Pi/2], 
           If[
           CloudObject`Private`\[Sigma]x$$ <= CloudObject`Private`\[Sigma]y$$,
             CloudObject`Private`\[Theta]s1$ + Pi/2, 
            CloudObject`Private`\[Theta]s1$ - Pi/2]]; 
        CloudObject`Private`\[Sigma]ave$ = (CloudObject`Private`\[Sigma]x$$ + 
           CloudObject`Private`\[Sigma]y$$)/2; 
        CloudObject`Private`R$ = 
         Sqrt[((CloudObject`Private`\[Sigma]x$$ - 
              CloudObject`Private`\[Sigma]y$$)/2)^2 + 
           CloudObject`Private`\[Tau]xy$$^2]; 
        CloudObject`Private`\[Tau]max1$ = CloudObject`Private`R$; 
        CloudObject`Private`\[Tau]max2$ = -CloudObject`Private`R$; 
        CloudObject`Private`\[Sigma]x1$ = 
         Chop[CloudObject`Private`\[Sigma]ave$ + ((
              CloudObject`Private`\[Sigma]x$$ - 
              CloudObject`Private`\[Sigma]y$$)/2) 
            Cos[2 CloudObject`Private`\[Theta]$] + 
           CloudObject`Private`\[Tau]xy$$ 
            Sin[2 CloudObject`Private`\[Theta]$]]; 
        CloudObject`Private`\[Sigma]y1$ = 
         Chop[CloudObject`Private`\[Sigma]ave$ - ((
             CloudObject`Private`\[Sigma]x$$ - 
             CloudObject`Private`\[Sigma]y$$)/2) 
           Cos[2 CloudObject`Private`\[Theta]$] - 
           CloudObject`Private`\[Tau]xy$$ 
           Sin[2 CloudObject`Private`\[Theta]$]]; 
        CloudObject`Private`\[Tau]x1y1$ = Chop[
           Switch[
           CloudObject`Private`path$$, 
            1, (-((CloudObject`Private`\[Sigma]x$$ - 
                CloudObject`Private`\[Sigma]y$$)/2)) 
             Sin[2 CloudObject`Private`\[Theta]$] + 
            CloudObject`Private`\[Tau]xy$$ 
             Cos[2 CloudObject`Private`\[Theta]$], 2, 0, 3, 
            CloudObject`Private`\[Tau]max1$]]; 
        CloudObject`Private`\[Sigma]1$ = 
         CloudObject`Private`\[Sigma]ave$ + CloudObject`Private`R$; 
        CloudObject`Private`\[Sigma]2$ = 
         CloudObject`Private`\[Sigma]ave$ - CloudObject`Private`R$; 
        CloudObject`Private`\[Theta]0$ = If[
           And[
           CloudObject`Private`\[Sigma]x$$ == 
            CloudObject`Private`\[Sigma]ave$, CloudObject`Private`\[Tau]xy$$ == 
            0], 0, 
           ArcTan[
           CloudObject`Private`\[Sigma]x$$ - CloudObject`Private`\[Sigma]ave$,
             CloudObject`Private`\[Tau]xy$$]]; CloudObject`Private`cx = Red; 
        CloudObject`Private`cy = Blue; 
        CloudObject`Private`cxy = RGBColor[0, 0.6, 0]; 
        CloudObject`Private`cod = 0.5; CloudObject`Private`stressplot$ = Plot[{
            If[
            CloudObject`Private`sx$$, 
             CloudObject`Private`\[Sigma]ave$ + ((
                CloudObject`Private`\[Sigma]x$$ - 
                CloudObject`Private`\[Sigma]y$$)/2) 
              Cos[(2 CloudObject`Private`x) Degree] + 
             CloudObject`Private`\[Tau]xy$$ 
              Sin[(2 CloudObject`Private`x) Degree], None], 
            If[
            CloudObject`Private`sy$$, 
             CloudObject`Private`\[Sigma]ave$ - ((
               CloudObject`Private`\[Sigma]x$$ - 
               CloudObject`Private`\[Sigma]y$$)/2) 
             Cos[(2 CloudObject`Private`x) Degree] - 
             CloudObject`Private`\[Tau]xy$$ 
             Sin[(2 CloudObject`Private`x) Degree], None], 
            If[
            CloudObject`Private`sxy$$, (-((CloudObject`Private`\[Sigma]x$$ - 
                 CloudObject`Private`\[Sigma]y$$)/2)) 
              Sin[(2 CloudObject`Private`x) Degree] + 
             CloudObject`Private`\[Tau]xy$$ 
              Cos[(2 CloudObject`Private`x) Degree], None]}, {
           CloudObject`Private`x, 0, 180}, 
           PlotStyle -> {{Thick, CloudObject`Private`cx}, {
             Thick, CloudObject`Private`cy}, {
             Thick, CloudObject`Private`cxy}}, 
           PlotRange -> {{-30, 
             200}, (2.4 CloudObject`Private`smax$$) {-1, 1}}, 
           AxesLabel -> {"\[Theta](\[Degree])", "\[Sigma] (MPa)"}, AxesStyle -> 
           Arrowheads[{0, 0.04}, {0, 0.04}], LabelStyle -> {12, Black}, 
           Ticks -> {{45, 90, 135, 180}, 
             Round[
             CloudObject`Private`smax$$ {-2., -1.5, -1, -0.5, 0.5, 1., 1.5, 
                2.}]}, AspectRatio -> Full, PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {None, 
              Scaled[0.02]}}, Epilog -> {
             Switch[CloudObject`Private`path$$, 1, {
               If[CloudObject`Private`sx$$, {
                 Text[
                  Framed[
                   Style[
                    Subscript["\[Sigma]", 
                    Row[{
                    Style["x", Italic], "'"}]], 12, CloudObject`Private`cx], 
                   Background -> White, FrameStyle -> 
                   Directive[CloudObject`Private`cx, 
                    Thickness[0.5]], FrameMargins -> Tiny], {
                  CloudObject`Private`\[Theta]d$$, 
                   CloudObject`Private`\[Sigma]x1$}, 1.5 {0, -1}], 
                 PointSize[0.02], CloudObject`Private`cx, 
                 
                 Point[{CloudObject`Private`\[Theta]$ (180/Pi), 
                   CloudObject`Private`\[Sigma]x1$}]}], 
               If[CloudObject`Private`sy$$, {
                 Text[
                  Framed[
                   Style[
                    Subscript["\[Sigma]", 
                    Row[{
                    Style["y", Italic], "'"}]], 12, CloudObject`Private`cy], 
                   Background -> White, FrameStyle -> 
                   Directive[CloudObject`Private`cy, 
                    Thickness[0.5]], FrameMargins -> Tiny], {
                  CloudObject`Private`\[Theta]d$$, 
                   CloudObject`Private`\[Sigma]y1$}, 1.5 {0, 1}], 
                 PointSize[0.02], CloudObject`Private`cy, 
                 
                 Point[{CloudObject`Private`\[Theta]$ (180/Pi), 
                   CloudObject`Private`\[Sigma]y1$}]}], 
               If[CloudObject`Private`sxy$$, {
                 Text[
                  Framed[
                   Style[
                    Subscript["\[Tau]", 
                    Row[{
                    Style["x", Italic], "\[InvisibleComma]", 
                    Style["y", Italic], "'"}]], 12, CloudObject`Private`cxy], 
                   Background -> White, FrameStyle -> 
                   Directive[CloudObject`Private`cxy, 
                    Thickness[0.5]], FrameMargins -> Tiny], {
                  CloudObject`Private`\[Theta]d$$, 
                   CloudObject`Private`\[Tau]x1y1$}, 1.5 {1, 0}], 
                 PointSize[0.02], CloudObject`Private`cxy, 
                 
                 Point[{CloudObject`Private`\[Theta]$ (180/Pi), 
                   CloudObject`Private`\[Tau]x1y1$}]}]}, 2, {
               If[CloudObject`Private`sx$$, {
                 Text[
                  Framed[
                   Style[
                    Subscript["\[Sigma]", 
                    Row[{
                    Style["1", Italic]}]], 12, CloudObject`Private`cx], 
                   Background -> White, FrameStyle -> 
                   Directive[CloudObject`Private`cx, 
                    Thickness[0.5]], FrameMargins -> Tiny], {
                  CloudObject`Private`\[Theta]d$$, 
                   CloudObject`Private`\[Sigma]x1$}, 1.5 {0, -1}], 
                 PointSize[0.02], CloudObject`Private`cx, 
                 
                 Point[{CloudObject`Private`\[Theta]$ (180/Pi), 
                   CloudObject`Private`\[Sigma]x1$}]}], 
               If[CloudObject`Private`sy$$, {
                 Text[
                  Framed[
                   Style[
                    Subscript["\[Sigma]", 
                    Row[{
                    Style["2", Italic]}]], 12, CloudObject`Private`cy], 
                   Background -> White, FrameStyle -> 
                   Directive[CloudObject`Private`cy, 
                    Thickness[0.5]], FrameMargins -> Tiny], {
                  CloudObject`Private`\[Theta]d$$, 
                   CloudObject`Private`\[Sigma]y1$}, 1.5 {0, 1}], 
                 PointSize[0.02], CloudObject`Private`cy, 
                 
                 Point[{CloudObject`Private`\[Theta]$ (180/Pi), 
                   CloudObject`Private`\[Sigma]y1$}]}], 
               If[CloudObject`Private`sxy$$, {
                 Text[
                  Framed[
                   Style[
                    Subscript["\[Tau]", 
                    Row[{
                    Style["x", Italic], "\[InvisibleComma]", 
                    Style["y", Italic], "'"}]], 12, CloudObject`Private`cxy], 
                   Background -> White, FrameStyle -> 
                   Directive[CloudObject`Private`cxy, 
                    Thickness[0.5]], FrameMargins -> Tiny], {
                  CloudObject`Private`\[Theta]d$$, 
                   CloudObject`Private`\[Tau]x1y1$}, 1.5 {1, 0}], 
                 PointSize[0.02], CloudObject`Private`cxy, 
                 
                 Point[{CloudObject`Private`\[Theta]$ (180/Pi), 
                   CloudObject`Private`\[Tau]x1y1$}]}]}, 3, {
               If[CloudObject`Private`sx$$, {
                 Text[
                  Framed[
                   Style[
                    Subscript["\[Sigma]", 
                    Row[{
                    Style["x", Italic], "'"}]], 12, CloudObject`Private`cx], 
                   Background -> White, FrameStyle -> 
                   Directive[CloudObject`Private`cx, 
                    Thickness[0.5]], FrameMargins -> Tiny], {
                  CloudObject`Private`\[Theta]d$$, 
                   CloudObject`Private`\[Sigma]x1$}, 1.5 {0, -1}], 
                 PointSize[0.02], CloudObject`Private`cx, 
                 
                 Point[{CloudObject`Private`\[Theta]$ (180/Pi), 
                   CloudObject`Private`\[Sigma]x1$}]}], 
               If[CloudObject`Private`sy$$, {
                 Text[
                  Framed[
                   Style[
                    Subscript["\[Sigma]", 
                    Row[{
                    Style["y", Italic], "'"}]], 12, CloudObject`Private`cy], 
                   Background -> White, FrameStyle -> 
                   Directive[CloudObject`Private`cy, 
                    Thickness[0.5]], FrameMargins -> Tiny], {
                  CloudObject`Private`\[Theta]d$$, 
                   CloudObject`Private`\[Sigma]y1$}, 1.5 {0, 1}], 
                 PointSize[0.02], CloudObject`Private`cy, 
                 
                 Point[{CloudObject`Private`\[Theta]$ (180/Pi), 
                   CloudObject`Private`\[Sigma]y1$}]}], 
               If[CloudObject`Private`sxy$$, {
                 Text[
                  Framed[
                   Style[
                    Subscript["\[Tau]", 
                    Row[{
                    Style["max", Italic]}]], 12, CloudObject`Private`cxy], 
                   Background -> White, FrameStyle -> 
                   Directive[CloudObject`Private`cxy, 
                    Thickness[0.5]], FrameMargins -> Tiny], {
                  CloudObject`Private`\[Theta]d$$, 
                   CloudObject`Private`\[Tau]x1y1$}, 1.5 {1, 0}], 
                 PointSize[0.02], CloudObject`Private`cxy, 
                 
                 Point[{CloudObject`Private`\[Theta]$ (180/Pi), 
                   CloudObject`Private`\[Tau]x1y1$}]}]}]}]; 
        CloudObject`Private`mohr$ = Graphics[{
            Thickness[0.005], 
            (Scale[#, {1, -1}, {0, 0}]& )[
             
             Circle[{CloudObject`Private`\[Sigma]ave$, 0}, 
              CloudObject`Private`R$]], 
            Thickness[0.001], 
            Text[
             Style["\[Sigma]", 15, Background -> White], 
             2 {CloudObject`Private`smax$$, 0}, {-2, -1.5}], 
            Text[
             Style["\[Tau]", 15, Background -> White], 
             2 {0, -CloudObject`Private`smax$$}, {3, 2}], 
            
            Arrow[{CloudObject`Private`smax$$ {-2.1, 0}, 
              CloudObject`Private`smax$$ {2.1, 0}}], 
            
            Arrow[{CloudObject`Private`smax$$ {0, 2.1}, 
              CloudObject`Private`smax$$ {0, -2.1}}], 
            If[CloudObject`Private`ticks$$, {
              Map[{
                Line[{{#, 0}, {#, (1/15) CloudObject`Private`smax$$}}], 
                Text[
                 Style[
                  Round[#], 12], {#, 0.2 CloudObject`Private`smax$$}]}& , 
               CloudObject`Private`smax$$ {-1.5, -1, -0.5, 0.5, 1., 1.5}], 
              Map[
              Line[{{0, #}, {(1/15) CloudObject`Private`smax$$, #}}]& , 
               CloudObject`Private`smax$$ {-1.5, -1, -0.5, 0.5, 1., 1.5}], 
              Map[Text[
                
                Style[-Round[#], 12], {((-2)/15) 
                 CloudObject`Private`smax$$, #}, {0.5, 0}]& , 
               CloudObject`Private`smax$$ {0.5, 1., 1.5}], 
              Map[Text[
                
                Style[-Round[#], 12], {((-2)/15) 
                 CloudObject`Private`smax$$, #}, {0.4, 0}]& , (-
                CloudObject`Private`smax$$) {0.5, 1., 1.5}]}]}, 
           PlotRange -> ({{-#, #}, {-#, #}}& )[
            2.2 CloudObject`Private`smax$$], PlotRangePadding -> {{None, 
              Scaled[0.02]}, {
              Scaled[0.02], None}}, Epilog -> {
             (Scale[#, {1, -1}, {0, 0}]& )[{{Dashed, 
                
                Line[{{CloudObject`Private`\[Sigma]ave$, 0}, {
                  CloudObject`Private`\[Sigma]x$$, 
                   CloudObject`Private`\[Tau]xy$$}}]}, {
                Thickness[0.005], 
                
                Line[{{CloudObject`Private`\[Sigma]ave$, 0}, {
                  CloudObject`Private`\[Sigma]x1$, 
                   CloudObject`Private`\[Tau]x1y1$}}]}, {
                Switch[CloudObject`Private`path$$, 1, {
                  PointSize[0.015], 
                  
                  Point[{CloudObject`Private`\[Sigma]x1$, 
                    CloudObject`Private`\[Tau]x1y1$}], 
                  
                  Point[{CloudObject`Private`\[Sigma]x$$, 
                    CloudObject`Private`\[Tau]xy$$}]}, 2, {
                  PointSize[0.015], 
                  Point[{CloudObject`Private`\[Sigma]1$, 0}], 
                  Point[{CloudObject`Private`\[Sigma]2$, 0}]}, 3, {
                  PointSize[0.015], 
                  
                  Point[{CloudObject`Private`\[Sigma]ave$, 
                    CloudObject`Private`\[Tau]max1$}]}]}, 
               If[CloudObject`Private`cs$$, {
                 PointSize[0.015], 
                 Point[{CloudObject`Private`\[Sigma]ave$, 0}], 
                 
                 Point[{CloudObject`Private`\[Sigma]x$$, 
                   CloudObject`Private`\[Tau]xy$$}], 
                 Point[{CloudObject`Private`\[Sigma]1$, 0}], 
                 Point[{CloudObject`Private`\[Sigma]2$, 0}], 
                 
                 Point[{CloudObject`Private`\[Sigma]ave$, 
                   CloudObject`Private`\[Tau]max1$}]}]}], 
             Switch[CloudObject`Private`path$$, 1, {
               Text[
                Style[
                 Style[
                  Subscript["\[Sigma]", "0"], Bold], 12, Background -> 
                 White], {
                 CloudObject`Private`\[Sigma]ave$, 0} + (
                  CloudObject`Private`R$ + (1/6) CloudObject`Private`smax$$) {
                   Cos[-CloudObject`Private`\[Theta]0$], 
                   Sin[-CloudObject`Private`\[Theta]0$]}], 
               If[CloudObject`Private`\[Theta]$ != 0, 
                Text[
                 Style[
                  Style["\[Sigma]'", Bold], 12, Background -> White], {
                  CloudObject`Private`\[Sigma]ave$, 0} + (
                   CloudObject`Private`R$ + (1/6) CloudObject`Private`smax$$) {
                    
                    Cos[-CloudObject`Private`\[Theta]0$ + 
                    2 CloudObject`Private`\[Theta]$], 
                    
                    Sin[-CloudObject`Private`\[Theta]0$ + 
                    2 CloudObject`Private`\[Theta]$]}]]}, 2, {
               Apply[Text[
                 Style[
                  Subscript["\[Sigma]", #], 12, Background -> White], {#2, 
                  3}, {#3, #4}]& , {{
                 1, CloudObject`Private`\[Sigma]1$, -1.5, -1.}, {
                 2, CloudObject`Private`\[Sigma]2$, 1.5, -1.}}, {1}]}, 3, {
               Apply[Text[
                 Style[
                  Row[{
                    Subscript["\[Tau]", "max"]}], 12, Background -> White], {
                 CloudObject`Private`\[Sigma]ave$, #}, {0, #2}]& , {{
                 CloudObject`Private`\[Tau]max2$, 1.5}}, {1}]}], 
             If[CloudObject`Private`cs$$, {
               Apply[Text[
                 Style[
                  Subscript["\[Sigma]", #], 12, Background -> White], {#2, 
                  3}, {#3, #4}]& , {{
                 1, CloudObject`Private`\[Sigma]1$, -1.5, -1.}, {
                 2, CloudObject`Private`\[Sigma]2$, 1.5, -1.}}, {1}], 
               Apply[Text[
                 Style[
                  Row[{
                    Subscript["\[Tau]", "max"]}], 12, Background -> White], {
                 CloudObject`Private`\[Sigma]ave$, #}, {0, #2}]& , {{
                 CloudObject`Private`\[Tau]max2$, 1.5}}, {1}]}], 
             (Scale[#, {1, -1}, {0, 0}]& )[{
               If[CloudObject`Private`pj$$, {Dashed, 
                 Thickness[0.003], 
                 
                 Line[{{CloudObject`Private`\[Sigma]x1$, 
                    CloudObject`Private`\[Tau]x1y1$}, {
                   CloudObject`Private`\[Sigma]x1$, 0}}], 
                 
                 Line[{{CloudObject`Private`\[Sigma]y1$, -
                    CloudObject`Private`\[Tau]x1y1$}, {
                   CloudObject`Private`\[Sigma]y1$, 0}}], 
                 
                 Line[{{CloudObject`Private`\[Sigma]y1$, -
                    CloudObject`Private`\[Tau]x1y1$}, {
                   CloudObject`Private`\[Sigma]ave$, 0}}], 
                 
                 Line[{{CloudObject`Private`\[Sigma]x1$, 
                    CloudObject`Private`\[Tau]x1y1$}, {
                   0, CloudObject`Private`\[Tau]x1y1$}}], 
                 PointSize[0.015], CloudObject`Private`cx, 
                 Point[{CloudObject`Private`\[Sigma]x1$, 0}], 
                 CloudObject`Private`cy, 
                 Point[{CloudObject`Private`\[Sigma]y1$, 0}], 
                 CloudObject`Private`cxy, 
                 Point[{0, CloudObject`Private`\[Tau]x1y1$}]}]}], 
             If[CloudObject`Private`pj$$, {CloudObject`Private`cx, 
               Text[
                Style[
                 Subscript["\[Sigma]", 
                  Row[{
                    Style["x", Italic], "'"}]], 12], {
                CloudObject`Private`\[Sigma]x1$, 0}, {0, 1}], 
               CloudObject`Private`cy, 
               Text[
                Style[
                 Subscript["\[Sigma]", 
                  Row[{
                    Style["y", Italic], "'"}]], 12], {
                CloudObject`Private`\[Sigma]y1$, 0}, {0, -1.5}], 
               CloudObject`Private`cxy, 
               Text[
                Subscript["\[Tau]", 
                 Row[{
                   Style["x", Italic], "\[InvisibleComma]'", 
                   Style["y", Italic], "'"}]], {
                0, -CloudObject`Private`\[Tau]x1y1$}, {1.5, 0}]}], 
             Arrowheads[0.02], 
             If[CloudObject`Private`\[Theta]$ != 0, 
              Rotate[
               Arrow[
                Map[N[
                  Table[{
                    Cos[CloudObject`Private`k], 
                    Sin[CloudObject`Private`k]} Part[#, 2] + Part[#, 1], {
                   CloudObject`Private`k, 
                    Part[#, 3], 
                    Part[#, 4], (Part[#, 4] - Part[#, 3])/Part[#, 5]}]]& , {{{
                   CloudObject`Private`\[Sigma]ave$, 0}, 0.4 
                   CloudObject`Private`R$, 0, 2 CloudObject`Private`\[Theta]$,
                    100}}]], -CloudObject`Private`\[Theta]0$, {
               CloudObject`Private`\[Sigma]ave$, 0}]], 
             If[CloudObject`Private`\[Theta]$ != 0, 
              Text[
               Style[
               "2\[Theta]", 10], {
                CloudObject`Private`\[Sigma]ave$, 0} + (0.7 
                 CloudObject`Private`R$) {
                  Cos[
                  CloudObject`Private`\[Theta]$ - 
                   CloudObject`Private`\[Theta]0$], 
                  Sin[
                  CloudObject`Private`\[Theta]$ - 
                   CloudObject`Private`\[Theta]0$]}]]}]; 
        CloudObject`Private`\[Theta]1$ = 
         ArcTan[CloudObject`Private`\[Tau]xy$$/(2 
           CloudObject`Private`smax$$)]; 
        CloudObject`Private`scale1$ = 
         Sqrt[1 + ((1/2) (Abs[CloudObject`Private`\[Tau]xy$$]/
              CloudObject`Private`smax$$))^2]; 
        CloudObject`Private`original$ = Graphics[{
            EdgeForm[
             Thickness[0.005]], 
            FaceForm[LightBlue], 
            Rectangle[Sqrt[2] {
               Cos[(-3) (Pi/4)], 
               Sin[(-3) (Pi/4)]}, Sqrt[2] {
               Cos[Pi/4], 
               Sin[Pi/4]}], {
             Thickness[0.003], 
             Arrowheads[0.03], 
             Arrow[{{0, 0}, 0.75 {1, 0}}], 
             Arrow[{{0, 0}, 0.75 {0, 1}}]}, {
             Apply[Text[
               Style[#, Italic, 12], {#2, #3}]& , {{"x", 0.6, -0.2}, {
               "y", -0.2, 0.6}}, {1}]}, 
            If[CloudObject`Private`\[Sigma]x$$ != 0, 
             Map[Text[
               Style[
                Subscript["\[Sigma]", 
                 Row[{
                   Style["x", Italic]}]], 14, CloudObject`Private`cx], (1.2 
                If[CloudObject`Private`\[Sigma]x$$ > 0, 1.1 + 
                  1 (CloudObject`Private`\[Sigma]x$$/
                    CloudObject`Private`smax$$), 1.1 - 
                  1 (CloudObject`Private`\[Sigma]x$$/
                   CloudObject`Private`smax$$)]) {
                 Cos[#], 
                 Sin[#]}]& , {0, Pi}]], 
            If[CloudObject`Private`\[Sigma]y$$ != 0, 
             Map[Text[
               Style[
                Subscript["\[Sigma]", 
                 Row[{
                   Style["y", Italic]}]], 14, CloudObject`Private`cy], (1.2 
                If[CloudObject`Private`\[Sigma]y$$ > 0, 1.1 + 
                  1 (CloudObject`Private`\[Sigma]y$$/
                    CloudObject`Private`smax$$), 1.1 - 
                  1 (CloudObject`Private`\[Sigma]y$$/
                   CloudObject`Private`smax$$)]) {
                 Cos[# (Pi/2)], 
                 Sin[# (Pi/2)]}]& , {1, -1}]], 
            If[CloudObject`Private`\[Tau]xy$$ != 0, 
             Map[Text[
               Style[
                Subscript["\[Tau]", 
                 Row[{
                   Style["x", Italic], 
                   Style["y", Italic]}]], 14, CloudObject`Private`cxy], (1.2 
                Sqrt[2]) {
                 Cos[# (Pi/4)], 
                 Sin[# (Pi/4)]}]& , {1, 5}]], 
            If[CloudObject`Private`\[Sigma]x$$ != 0, {
              Arrowheads[
               If[
               CloudObject`Private`\[Sigma]x$$ > 
                0, {{0.04, 1}}, {{-0.04, 0}}]], CloudObject`Private`cx, 
              Thickness[0.005], 
              Map[Arrow[{1.2 {
                   Cos[#], 
                   Sin[#]}, 
                 If[
                  CloudObject`Private`\[Sigma]x$$ > 0, 1.2 + 
                   CloudObject`Private`\[Sigma]x$$/CloudObject`Private`smax$$,
                    1.2 - CloudObject`Private`\[Sigma]x$$/
                   CloudObject`Private`smax$$] {
                   Cos[#], 
                   Sin[#]}}]& , {0, Pi}]}], 
            If[CloudObject`Private`\[Sigma]y$$ != 0, {
              Arrowheads[
               If[
               CloudObject`Private`\[Sigma]y$$ > 
                0, {{0.04, 1}}, {{-0.04, 0}}]], CloudObject`Private`cy, 
              Thickness[0.005], 
              Map[Arrow[{1.2 {
                   Cos[# (Pi/2)], 
                   Sin[# (Pi/2)]}, 
                 If[CloudObject`Private`\[Sigma]y$$ > 0, 1.2 + 
                   CloudObject`Private`\[Sigma]y$$/CloudObject`Private`smax$$,
                    1.2 - CloudObject`Private`\[Sigma]y$$/
                   CloudObject`Private`smax$$] {
                   Cos[# (Pi/2)], 
                   Sin[# (Pi/2)]}}]& , {1, -1}]}], 
            If[CloudObject`Private`\[Tau]xy$$ != 0, {
              Arrowheads[0.04], CloudObject`Private`cxy, 
              Thickness[0.005], 
              Apply[Arrow[{(CloudObject`Private`scale1$ 1.1) {
                   Cos[# - #2 CloudObject`Private`\[Theta]1$], 
                   Sin[# - #2 CloudObject`Private`\[Theta]1$]}, (
                  CloudObject`Private`scale1$ 1.1) {
                   Cos[# + #2 CloudObject`Private`\[Theta]1$], 
                   Sin[# + #2 CloudObject`Private`\[Theta]1$]}}]& , {{0, 1}, {
                Pi/2, -1}, {Pi, 1}, {(-Pi)/2, -1}}, {1}]}]}, 
           PlotRange -> ({{-#, #}, {-#, #}}& )[3.4], ImageSize -> {260, 260}, 
           AspectRatio -> Full]; CloudObject`Private`coordinate$ = Graphics[{
            Thickness[0.003], 
            Arrowheads[0.05], 
            Apply[
            Arrow[{{0, 0}, (CloudObject`Private`cod 1.8) {#, #2}}]& , {{1, 
             0}, {0, 1}}, {1}], 
            If[CloudObject`Private`\[Theta]$ != 0, 
             Apply[Arrow[{{0, 0}, (CloudObject`Private`cod 1.8) {#, #2}}]& , {{
                Cos[CloudObject`Private`\[Theta]$], 
                Sin[CloudObject`Private`\[Theta]$]}, {
                Cos[CloudObject`Private`\[Theta]$ + Pi/2], 
                Sin[CloudObject`Private`\[Theta]$ + Pi/2]}}, {1}]], 
            Apply[Text[
              Style[#, Italic, 12], {#2, #3}]& , {{
              "x", CloudObject`Private`cod 1.7, 
               CloudObject`Private`cod (-0.2)}, {
              "y", CloudObject`Private`cod (-0.2), CloudObject`Private`cod 
               1.7}}, {1}], 
            If[CloudObject`Private`\[Theta]$ != 0, 
             Apply[Text[
               Style[
                Row[{
                  Spacer[2.8], #, "'"}], Italic, 12], {#2, #3}]& , {{
               "x", (CloudObject`Private`cod 1.7) 
                Cos[CloudObject`Private`\[Theta]$], 
                CloudObject`Private`cod (
                 1.7 Sin[CloudObject`Private`\[Theta]$] - 0.2)}, {
               "y", CloudObject`Private`cod (
                 1.7 Cos[CloudObject`Private`\[Theta]$ + Pi/2] - 0.2), (
                 CloudObject`Private`cod 1.7) 
                Sin[CloudObject`Private`\[Theta]$ + Pi/2]}}, {1}]], 
            If[CloudObject`Private`\[Theta]$ != 0, {
              Arrow[
               Map[N[
                 Table[{
                    Cos[CloudObject`Private`k], 
                    Sin[CloudObject`Private`k]} Part[#, 2] + Part[#, 1], {
                  CloudObject`Private`k, 
                   Part[#, 3], 
                   Part[#, 4], (Part[#, 4] - Part[#, 3])/Part[#, 5]}]]& , {{{
                  0, 0}, CloudObject`Private`cod 1., 0, 
                  CloudObject`Private`\[Theta]$, 100}}]], 
              Text[
               Style["\[Theta]", 12], 
               CloudObject`Private`cod {
                1.2 Cos[CloudObject`Private`\[Theta]$/2], 1.2 
                 Sin[CloudObject`Private`\[Theta]$/2]}]}]}, 
           PlotRange -> ({{-#, #}, {-#, #}}& )[CloudObject`Private`cod 2.], 
           ImageSize -> 0.7 {200, 200}, AspectRatio -> Full]; 
        CloudObject`Private`\[Theta]2$ = 
         ArcTan[CloudObject`Private`\[Tau]x1y1$/(2 
           CloudObject`Private`smax$$)]; 
        CloudObject`Private`scale2$ = 
         Sqrt[
          1 + ((1/2) (Abs[CloudObject`Private`\[Tau]x1y1$]/
              CloudObject`Private`smax$$))^2]; 
        CloudObject`Private`diffelement$ = Graphics[{
            EdgeForm[
             Thickness[0.005]], 
            FaceForm[LightBlue], 
            Rotate[
             Rectangle[Sqrt[2] {
                Cos[(-3) (Pi/4)], 
                Sin[(-3) (Pi/4)]}, Sqrt[2] {
                Cos[Pi/4], 
                Sin[Pi/4]}], CloudObject`Private`\[Theta]$, {0, 0}], {
             Thickness[0.003], 
             Arrowheads[0.03], 
             Apply[Arrow[{{0, 0}, 0.75 {#, #2}}]& , {{
                Cos[CloudObject`Private`\[Theta]$], 
                Sin[CloudObject`Private`\[Theta]$]}, {
                Cos[CloudObject`Private`\[Theta]$ + Pi/2], 
                Sin[CloudObject`Private`\[Theta]$ + Pi/2]}}, {1}]}, {
             Apply[Text[
               Style[
                Row[{#, "'"}], Italic, 12], {#2, #3}]& , {{
               "x", 0.6 Cos[CloudObject`Private`\[Theta]$], 
                0.6 Sin[CloudObject`Private`\[Theta]$] - 0.2}, {
               "y", 0.6 Cos[CloudObject`Private`\[Theta]$ + Pi/2] - 0.2, 0.6 
                Sin[CloudObject`Private`\[Theta]$ + Pi/2]}}, {1}]}, {
             Switch[CloudObject`Private`path$$, 1, {
               If[CloudObject`Private`\[Sigma]x1$ != 0, 
                Map[Text[
                  Style[
                   Subscript["\[Sigma]", 
                    Row[{
                    Style["x", Italic], "'"}]], 14, CloudObject`Private`cx], (
                   1.2 If[CloudObject`Private`\[Sigma]x1$ > 0, 1.1 + 
                    1 (CloudObject`Private`\[Sigma]x1$/
                    CloudObject`Private`smax$$), 1.1 - 
                    1 (CloudObject`Private`\[Sigma]x1$/
                    CloudObject`Private`smax$$)]) {
                    Cos[CloudObject`Private`\[Theta]$ + #], 
                    Sin[CloudObject`Private`\[Theta]$ + #]}]& , {0, Pi}]], 
               If[CloudObject`Private`\[Sigma]y1$ != 0, 
                Map[Text[
                  Style[
                   Subscript["\[Sigma]", 
                    Row[{
                    Style["y", Italic], "'"}]], 14, CloudObject`Private`cy], (
                   1.2 If[CloudObject`Private`\[Sigma]y1$ > 0, 1.1 + 
                    1 (CloudObject`Private`\[Sigma]y1$/
                    CloudObject`Private`smax$$), 1.1 - 
                    1 (CloudObject`Private`\[Sigma]y1$/
                    CloudObject`Private`smax$$)]) {
                    Cos[CloudObject`Private`\[Theta]$ + # (Pi/2)], 
                    Sin[CloudObject`Private`\[Theta]$ + # (Pi/2)]}]& , {
                 1, -1}]], 
               If[CloudObject`Private`\[Tau]x1y1$ != 0, 
                Map[Text[
                  Style[
                   Subscript["\[Tau]", 
                    Row[{
                    Style["x", Italic], "\[InvisibleComma]'", 
                    Style["y", Italic], "'"}]], 14, 
                   CloudObject`Private`cxy], (1.2 Sqrt[2]) {
                    Cos[CloudObject`Private`\[Theta]$ + # (Pi/4)], 
                    Sin[CloudObject`Private`\[Theta]$ + # (Pi/4)]}]& , {1, 
                 5}]], 
               If[CloudObject`Private`\[Sigma]x1$ != 0, {
                 Arrowheads[
                  If[
                  CloudObject`Private`\[Sigma]x1$ > 
                   0, {{0.04, 1}}, {{-0.04, 0}}]], CloudObject`Private`cx, 
                 Thickness[0.005], 
                 Map[Arrow[{1.2 {
                    Cos[CloudObject`Private`\[Theta]$ + #], 
                    Sin[CloudObject`Private`\[Theta]$ + #]}, 
                    If[CloudObject`Private`\[Sigma]x1$ > 0, 1.2 + 
                    CloudObject`Private`\[Sigma]x1$/
                    CloudObject`Private`smax$$, 1.2 - 
                    CloudObject`Private`\[Sigma]x1$/
                    CloudObject`Private`smax$$] {
                    Cos[CloudObject`Private`\[Theta]$ + #], 
                    Sin[CloudObject`Private`\[Theta]$ + #]}}]& , {0, Pi}]}], 
               If[CloudObject`Private`\[Sigma]y1$ != 0, {
                 Arrowheads[
                  If[
                  CloudObject`Private`\[Sigma]y1$ > 
                   0, {{0.04, 1}}, {{-0.04, 0}}]], CloudObject`Private`cy, 
                 Thickness[0.005], 
                 Map[Arrow[{1.2 {
                    Cos[CloudObject`Private`\[Theta]$ + # (Pi/2)], 
                    Sin[CloudObject`Private`\[Theta]$ + # (Pi/2)]}, 
                    If[CloudObject`Private`\[Sigma]y1$ > 0, 1.2 + 
                    CloudObject`Private`\[Sigma]y1$/
                    CloudObject`Private`smax$$, 1.2 - 
                    CloudObject`Private`\[Sigma]y1$/
                    CloudObject`Private`smax$$] {
                    Cos[CloudObject`Private`\[Theta]$ + # (Pi/2)], 
                    Sin[CloudObject`Private`\[Theta]$ + # (Pi/2)]}}]& , {
                  1, -1}]}], 
               If[CloudObject`Private`\[Tau]x1y1$ != 0, {
                 Arrowheads[0.04], CloudObject`Private`cxy, 
                 Thickness[0.005], 
                 Apply[Arrow[{(CloudObject`Private`scale2$ 1.1) {
                    Cos[
                    CloudObject`Private`\[Theta]$ + # - #2 
                    CloudObject`Private`\[Theta]2$], 
                    Sin[
                    CloudObject`Private`\[Theta]$ + # - #2 
                    CloudObject`Private`\[Theta]2$]}, (
                    CloudObject`Private`scale2$ 1.1) {
                    Cos[
                    CloudObject`Private`\[Theta]$ + # + #2 
                    CloudObject`Private`\[Theta]2$], 
                    Sin[
                    CloudObject`Private`\[Theta]$ + # + #2 
                    CloudObject`Private`\[Theta]2$]}}]& , {{0, 1}, {
                   Pi/2, -1}, {Pi, 1}, {(-Pi)/2, -1}}, {1}]}]}, 2, {
               If[CloudObject`Private`\[Sigma]x1$ != 0, 
                Map[Text[
                  Style[
                   Subscript["\[Sigma]", 
                    Style["1", Italic]], 14, CloudObject`Private`cx], (1.2 
                   If[CloudObject`Private`\[Sigma]x1$ > 0, 1.1 + 
                    1 (CloudObject`Private`\[Sigma]x1$/
                    CloudObject`Private`smax$$), 1.1 - 
                    1 (CloudObject`Private`\[Sigma]x1$/
                    CloudObject`Private`smax$$)]) {
                    Cos[CloudObject`Private`\[Theta]$ + #], 
                    Sin[CloudObject`Private`\[Theta]$ + #]}]& , {0, Pi}]], 
               If[CloudObject`Private`\[Sigma]y1$ != 0, 
                Map[Text[
                  Style[
                   Subscript["\[Sigma]", 
                    Style["2", Italic]], 14, CloudObject`Private`cy], (1.2 
                   If[CloudObject`Private`\[Sigma]y1$ > 0, 1.1 + 
                    1 (CloudObject`Private`\[Sigma]y1$/
                    CloudObject`Private`smax$$), 1.1 - 
                    1 (CloudObject`Private`\[Sigma]y1$/
                    CloudObject`Private`smax$$)]) {
                    Cos[CloudObject`Private`\[Theta]$ + # (Pi/2)], 
                    Sin[CloudObject`Private`\[Theta]$ + # (Pi/2)]}]& , {
                 1, -1}]], 
               If[CloudObject`Private`\[Sigma]x1$ != 0, {
                 Arrowheads[
                  If[
                  CloudObject`Private`\[Sigma]x1$ > 
                   0, {{0.04, 1}}, {{-0.04, 0}}]], CloudObject`Private`cx, 
                 Thickness[0.005], 
                 Map[Arrow[{1.2 {
                    Cos[CloudObject`Private`\[Theta]$ + #], 
                    Sin[CloudObject`Private`\[Theta]$ + #]}, 
                    If[CloudObject`Private`\[Sigma]x1$ > 0, 1.2 + 
                    CloudObject`Private`\[Sigma]x1$/
                    CloudObject`Private`smax$$, 1.2 - 
                    CloudObject`Private`\[Sigma]x1$/
                    CloudObject`Private`smax$$] {
                    Cos[CloudObject`Private`\[Theta]$ + #], 
                    Sin[CloudObject`Private`\[Theta]$ + #]}}]& , {0, Pi}]}], 
               If[CloudObject`Private`\[Sigma]y1$ != 0, {
                 Arrowheads[
                  If[
                  CloudObject`Private`\[Sigma]y1$ > 
                   0, {{0.04, 1}}, {{-0.04, 0}}]], CloudObject`Private`cy, 
                 Thickness[0.005], 
                 Map[Arrow[{1.2 {
                    Cos[CloudObject`Private`\[Theta]$ + # (Pi/2)], 
                    Sin[CloudObject`Private`\[Theta]$ + # (Pi/2)]}, 
                    If[CloudObject`Private`\[Sigma]y1$ > 0, 1.2 + 
                    CloudObject`Private`\[Sigma]y1$/
                    CloudObject`Private`smax$$, 1.2 - 
                    CloudObject`Private`\[Sigma]y1$/
                    CloudObject`Private`smax$$] {
                    Cos[CloudObject`Private`\[Theta]$ + # (Pi/2)], 
                    Sin[CloudObject`Private`\[Theta]$ + # (Pi/2)]}}]& , {
                  1, -1}]}]}, 3, {
               If[CloudObject`Private`\[Sigma]x1$ != 0, 
                Map[Text[
                  Style[
                   Subscript["\[Sigma]", 
                    Row[{
                    Style["x", Italic], "'"}]], 14, CloudObject`Private`cx], (
                   1.2 If[CloudObject`Private`\[Sigma]x1$ > 0, 1.1 + 
                    1 (CloudObject`Private`\[Sigma]x1$/
                    CloudObject`Private`smax$$), 1.1 - 
                    1 (CloudObject`Private`\[Sigma]x1$/
                    CloudObject`Private`smax$$)]) {
                    Cos[CloudObject`Private`\[Theta]$ + #], 
                    Sin[CloudObject`Private`\[Theta]$ + #]}]& , {0, Pi}]], 
               If[CloudObject`Private`\[Sigma]y1$ != 0, 
                Map[Text[
                  Style[
                   Subscript["\[Sigma]", 
                    Row[{
                    Style["y", Italic], "'"}]], 14, CloudObject`Private`cy], (
                   1.2 If[CloudObject`Private`\[Sigma]y1$ > 0, 1.1 + 
                    1 (CloudObject`Private`\[Sigma]y1$/
                    CloudObject`Private`smax$$), 1.1 - 
                    1 (CloudObject`Private`\[Sigma]y1$/
                    CloudObject`Private`smax$$)]) {
                    Cos[CloudObject`Private`\[Theta]$ + # (Pi/2)], 
                    Sin[CloudObject`Private`\[Theta]$ + # (Pi/2)]}]& , {
                 1, -1}]], 
               If[CloudObject`Private`\[Tau]x1y1$ != 0, 
                Map[Text[
                  Style[
                   Subscript["\[Tau]", 
                    Style["max", Italic]], 14, CloudObject`Private`cxy], (1.2 
                   Sqrt[2]) {
                    Cos[CloudObject`Private`\[Theta]$ + # (Pi/4)], 
                    Sin[CloudObject`Private`\[Theta]$ + # (Pi/4)]}]& , {1, 
                 5}]], 
               If[CloudObject`Private`\[Sigma]x1$ != 0, {
                 Arrowheads[
                  If[
                  CloudObject`Private`\[Sigma]x1$ > 
                   0, {{0.04, 1}}, {{-0.04, 0}}]], CloudObject`Private`cx, 
                 Thickness[0.005], 
                 Map[Arrow[{1.2 {
                    Cos[CloudObject`Private`\[Theta]$ + #], 
                    Sin[CloudObject`Private`\[Theta]$ + #]}, 
                    If[CloudObject`Private`\[Sigma]x1$ > 0, 1.2 + 
                    CloudObject`Private`\[Sigma]x1$/
                    CloudObject`Private`smax$$, 1.2 - 
                    CloudObject`Private`\[Sigma]x1$/
                    CloudObject`Private`smax$$] {
                    Cos[CloudObject`Private`\[Theta]$ + #], 
                    Sin[CloudObject`Private`\[Theta]$ + #]}}]& , {0, Pi}]}], 
               If[CloudObject`Private`\[Sigma]y1$ != 0, {
                 Arrowheads[
                  If[
                  CloudObject`Private`\[Sigma]y1$ > 
                   0, {{0.04, 1}}, {{-0.04, 0}}]], CloudObject`Private`cy, 
                 Thickness[0.005], 
                 Map[Arrow[{1.2 {
                    Cos[CloudObject`Private`\[Theta]$ + # (Pi/2)], 
                    Sin[CloudObject`Private`\[Theta]$ + # (Pi/2)]}, 
                    If[CloudObject`Private`\[Sigma]y1$ > 0, 1.2 + 
                    CloudObject`Private`\[Sigma]y1$/
                    CloudObject`Private`smax$$, 1.2 - 
                    CloudObject`Private`\[Sigma]y1$/
                    CloudObject`Private`smax$$] {
                    Cos[CloudObject`Private`\[Theta]$ + # (Pi/2)], 
                    Sin[CloudObject`Private`\[Theta]$ + # (Pi/2)]}}]& , {
                  1, -1}]}], 
               If[CloudObject`Private`\[Tau]x1y1$ != 0, {
                 Arrowheads[0.04], CloudObject`Private`cxy, 
                 Thickness[0.005], 
                 Apply[Arrow[{(CloudObject`Private`scale2$ 1.1) {
                    Cos[
                    CloudObject`Private`\[Theta]$ + # - #2 
                    CloudObject`Private`\[Theta]2$], 
                    Sin[
                    CloudObject`Private`\[Theta]$ + # - #2 
                    CloudObject`Private`\[Theta]2$]}, (
                    CloudObject`Private`scale2$ 1.1) {
                    Cos[
                    CloudObject`Private`\[Theta]$ + # + #2 
                    CloudObject`Private`\[Theta]2$], 
                    Sin[
                    CloudObject`Private`\[Theta]$ + # + #2 
                    CloudObject`Private`\[Theta]2$]}}]& , {{0, 1}, {
                   Pi/2, -1}, {Pi, 1}, {(-Pi)/2, -1}}, {1}]}]}]}}, 
           PlotRange -> ({{-#, #}, {-#, #}}& )[3.4], ImageSize -> {260, 260}, 
           AspectRatio -> Full]; CloudObject`Private`table0$ = Text[
           Style[
            Grid[{
              Apply[Subscript[#, #2]& , {{"\[Sigma]", 
                 Row[{
                   Style["x", Italic]}]}, {"\[Sigma]", 
                 Row[{
                   Style["y", Italic]}]}, {"\[Tau]", 
                 Row[{
                   Style["x", Italic], 
                   Style["y", Italic]}]}}, {1}], 
              Map[NumberForm[
                N[#], {4, 1}]& , {
               CloudObject`Private`\[Sigma]x$$, 
                CloudObject`Private`\[Sigma]y$$, 
                CloudObject`Private`\[Tau]xy$$}]}, Frame -> All, ItemSize -> 
             4, Alignment -> {Center, Center}], 15]]; 
        CloudObject`Private`table$ = Switch[CloudObject`Private`path$$, 1, 
           Text[
            Style[
             Grid[{
               Apply[Subscript[#, #2]& , {{"\[Sigma]", 
                  Row[{
                    Style["x", Italic], "'"}]}, {"\[Sigma]", 
                  Row[{
                    Style["y", Italic], "'"}]}, {"\[Tau]", 
                  Row[{
                    Style["x", Italic], "'\[InvisibleComma]", 
                    Style["y", Italic], "'"}]}}, {1}], 
               Map[NumberForm[
                 N[#], {4, 1}]& , {
                CloudObject`Private`\[Sigma]x1$, 
                 CloudObject`Private`\[Sigma]y1$, 
                 CloudObject`Private`\[Tau]x1y1$}]}, Frame -> All, ItemSize -> 
              4, Alignment -> {Center, Center}], 15]], 2, 
           Text[
            Style[
             Grid[{
               Apply[Subscript[#, #2]& , {{"\[Sigma]", 
                  Row[{
                    Style["1", Italic]}]}, {"\[Sigma]", 
                  Row[{
                    Style["2", Italic]}]}, {"\[Tau]", 
                  Row[{
                    Style["x", Italic], "'\[InvisibleComma]", 
                    Style["y", Italic], "'"}]}}, {1}], 
               Map[NumberForm[
                 N[#], {4, 1}]& , {
                CloudObject`Private`\[Sigma]x1$, 
                 CloudObject`Private`\[Sigma]y1$, 
                 CloudObject`Private`\[Tau]x1y1$}]}, Frame -> All, ItemSize -> 
              4, Alignment -> {Center, Center}], 15]], 3, 
           Text[
            Style[
             Grid[{
               Apply[Subscript[#, #2]& , {{"\[Sigma]", 
                  Row[{
                    Style["x", Italic], "'"}]}, {"\[Sigma]", 
                  Row[{
                    Style["y", Italic], "'"}]}, {"\[Tau]", 
                  Row[{
                    Style["max", Italic]}]}}, {1}], 
               Map[NumberForm[
                 N[#], {4, 1}]& , {
                CloudObject`Private`\[Sigma]x1$, 
                 CloudObject`Private`\[Sigma]y1$, 
                 CloudObject`Private`\[Tau]x1y1$}]}, Frame -> All, ItemSize -> 
              4, Alignment -> {Center, Center}], 15]]]; Grid[{{
            Grid[{{
               Column[{
                 Text[
                  Style[
                   Row[{
                    Style[
                    Subscript["\[Sigma]", "0"], Bold], ", ", 
                    "stresses (MPa) at \[Theta] = ", 
                    NumberForm[0, {4, 1}], "\[Degree]"}], 15]], 
                 CloudObject`Private`table0$}, Center], Null, 
               Column[{
                 Text[
                  Style[
                   Row[{
                    Style["\[Sigma]'", Bold], ", ", 
                    "stresses (MPa) at \[Theta] = ", 
                    NumberForm[
                    CloudObject`Private`\[Theta]$ (180/Pi), {4, 1}], 
                    "\[Degree]"}], 15]], CloudObject`Private`table$}, 
                Center]}, {
              CloudObject`Private`original$, CloudObject`Private`coordinate$, 
               CloudObject`Private`diffelement$}, {
               Text[
                Style["Original Coordinates", 15, Bold]], Null, 
               Text[
                Style["Rotated Coordinates", 15, Bold]]}}], 
            If[CloudObject`Private`rightplot$$ == 5, 
             Show[
              Switch[
              CloudObject`Private`plottype$$, 1, 
               CloudObject`Private`stressplot$, 2, CloudObject`Private`mohr$],
               ImageSize -> {340, 350}]]}}, Alignment -> Center]], 
      "Specifications" :> {{{
         CloudObject`Private`\[Sigma]x$$, CloudObject`Private`smax$$, 
          Row[{
            Subscript["\[Sigma]", 
             Style["x", Italic]], 
            Spacer[4.5]}]}, 
         Dynamic[-CloudObject`Private`smax$$], 
         Dynamic[CloudObject`Private`smax$$], 0.1, Appearance -> "Labeled", 
         ControlPlacement -> 1}, {{CloudObject`Private`\[Sigma]y$$, 0, 
          Row[{
            Subscript["\[Sigma]", 
             Style["y", Italic]], 
            Spacer[3]}]}, 
         Dynamic[-CloudObject`Private`smax$$], 
         Dynamic[CloudObject`Private`smax$$], 0.1, Appearance -> "Labeled", 
         ControlPlacement -> 2}, {{CloudObject`Private`\[Tau]xy$$, 0, 
          Row[{
            Subscript["\[Tau]", 
             Style["x\[InvisibleComma]y", Italic]]}]}, 
         Dynamic[-CloudObject`Private`smax$$], 
         Dynamic[CloudObject`Private`smax$$], 0.1, Appearance -> "Labeled", 
         ControlPlacement -> 3}, {{CloudObject`Private`path$$, 1, ""}, {
         1 -> Style[
            Row[{"orientation", 
              Spacer[32.5]}], 12], 2 -> Style[
            Row[{"principal ", "stresses"}], 12], 3 -> Style[
            Row[{"max shear stress", 
              Spacer[3]}], 12]}, ControlType -> SetterBar, Appearance -> 
         "Vertical", BaselinePosition -> Center, ControlPlacement -> 4}, {{
         CloudObject`Private`\[Theta]d$$, 0, 
          Row[{"\[Theta]", 
            Spacer[2], "(\[Degree])"}]}, 0, 180, 0.1, ImageSize -> 100, 
         ControlPlacement -> 5}, {{CloudObject`Private`rightplot$$, 0, 
          Row[{"right plot", 
            Spacer[12]}]}, {5 -> "On", 0 -> "Off"}, ControlType -> SetterBar, 
         ControlPlacement -> 6}, {{CloudObject`Private`plottype$$, 1, 
          Row[{"plot type", 
            Spacer[14.5]}]}, {1 -> " stress plot ", 2 -> " Mohr's circle "}, 
         ControlType -> SetterBar, ControlPlacement -> 7}, {{
         CloudObject`Private`sx$$, True, 
          Subscript["\[Sigma]", 
           Style["x", Italic]]}, {True, False}, ControlPlacement -> 8}, {{
         CloudObject`Private`sy$$, False, 
          Subscript["\[Sigma]", 
           Style["y", Italic]]}, {True, False}, ControlPlacement -> 9}, {{
         CloudObject`Private`sxy$$, False, 
          Subscript["\[Tau]", 
           Style["xy", Italic]]}, {True, False}, ControlPlacement -> 10}, {{
         CloudObject`Private`pj$$, False, "resolution"}, {True, False}, 
         ControlPlacement -> 11}, {{
         CloudObject`Private`cs$$, False, "principle stress labels"}, {
         True, False}, ControlPlacement -> 12}, {{
         CloudObject`Private`ticks$$, False, "axes ticks"}, {True, False}, 
         ControlPlacement -> 13}, 
        Grid[{{
           Grid[{{
              Text[
               Style[
                Row[{
                  Style[
                   Subscript["\[Sigma]", "0"], Bold], ", ", 
                  "stresses (MPa) at \[Theta] = ", 
                  NumberForm[0, {4, 1}], "\[Degree]"}], 12]]}, {
              Manipulate`Place[1]}, {
              Manipulate`Place[2]}, {
              Manipulate`Place[3]}}, Alignment -> {Left, Center}], 
           Grid[{{
              Manipulate`Place[4], 
              PaneSelector[{1 -> Row[{
                   Spacer[5], 
                   Manipulate`Place[5], 
                   Spacer[10], 
                   Dynamic[
                    NumberForm[CloudObject`Private`\[Theta]d$$, {4, 1}]]}]}, 
               Dynamic[CloudObject`Private`path$$]]}}, 
            Alignment -> {Left, Top}, Spacings -> {1., 1.}], 
           Grid[{{
              Manipulate`Place[6]}, {
              PaneSelector[{5 -> Manipulate`Place[7]}, 
               Dynamic[CloudObject`Private`rightplot$$]]}, {
              PaneSelector[{6 -> Row[{
                   Manipulate`Place[8], 
                   Manipulate`Place[9], 
                   Manipulate`Place[10]}, 
                  Spacer[10]], 7 -> Grid[{{
                    Manipulate`Place[11], 
                    Manipulate`Place[12], 
                    Manipulate`Place[13]}}, Spacings -> {{0, 1., 1.}, 0}]}, 
               Dynamic[
               CloudObject`Private`rightplot$$ + 
                CloudObject`Private`plottype$$]]}}, 
            Alignment -> {Left, Center}, Spacings -> {1., {0, 0.8, 0.8}}]}}, 
         Alignment -> Top, Spacings -> {{0, 5, 8}, Automatic}], {{
         CloudObject`Private`smax$$, 100}, 0, ControlType -> None}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{1537., {381., 390.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center],

Cell["\<\
Reference: Nick Bongiardina, Jeffery Knutsen, Rachael L. Baumann and John L. \
Falconer, Mohr\[CloseCurlyQuote]s Circle and Stress Transformations (2016). \
Demonstration module available on the Mathematica demonstration project \
website, http://demonstrations.wolfram.com/\
MohrsCircleAndStressTransformations/. \
\>", "Text"]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 298, 8, 230, "Title"],
Cell[1787, 45, 1424, 39, 162, "Text"],
Cell[3214, 86, 1519, 51, 166, "Text"],
Cell[4736, 139, 97, 2, 45, "Text"],
Cell[4836, 143, 837, 28, 65, "Text"],
Cell[5676, 173, 1153, 30, 134, "Text"],
Cell[6832, 205, 61775, 1285, 795, "Output"],
Cell[68610, 1492, 338, 6, 74, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature kvTNb3LvewNpxDwwbIZBSMqH *)
